==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWidgets/QStyleHintReturnMask_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qstyleoption.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStyleHintReturnMask(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleHintReturnMask")
    QStyleHintReturnMask *_ptr = reinterpret_cast<QStyleHintReturnMask *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStyleHintReturnMask()
void __qt_construct_QStyleHintReturnMask_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturnMask()")
    Q_UNUSED(__java_arguments)
    QStyleHintReturnMask *__qt_this = new(__qtjambi_ptr) QStyleHintReturnMask();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QStyleHintReturnMask
void __qt_destruct_QStyleHintReturnMask(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleHintReturnMask")
    reinterpret_cast<QStyleHintReturnMask*>(ptr)->~QStyleHintReturnMask();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleHintReturnMask::QStyleHintReturnMask()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnMask_initialize_1native__Lio_qt_widgets_QStyleHintReturnMask_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleHintReturnMask::QStyleHintReturnMask()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleHintReturnMask_0, sizeof(QStyleHintReturnMask), typeid(QStyleHintReturnMask), false, &deleter_QStyleHintReturnMask, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnMask_setRegion_1native_1cref_1QRegion__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID region0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturnMask *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturnMask>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QRegion& __qt_region0 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(region0);
        __qt_this->region = __qt_region0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnMask_region_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturnMask *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturnMask>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QRegion&  __qt_value = __qt_this->region;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnMask_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleHintReturnMask *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturnMask>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleHintReturnMask(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleHintReturnMask>("QStyleHintReturnMask", "io/qt/widgets/QStyleHintReturnMask");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleHintReturnMask, {
        ConstructorInfo(&__qt_construct_QStyleHintReturnMask_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleHintReturnMask);
    registerMetaType<QStyleHintReturnMask>("QStyleHintReturnMask");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiWidgets/QStyleHintReturnMask_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qstyleoption.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStyleHintReturnMask(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleHintReturnMask")
    QStyleHintReturnMask *_ptr = reinterpret_cast<QStyleHintReturnMask *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStyleHintReturnMask()
void __qt_construct_QStyleHintReturnMask(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturnMask()")
    Q_UNUSED(__java_arguments)
    QStyleHintReturnMask *__qt_this = new(__qtjambi_ptr) QStyleHintReturnMask();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QStyleHintReturnMask::QStyleHintReturnMask()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnMask_initialize_1native__Lio_qt_widgets_QStyleHintReturnMask_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleHintReturnMask::QStyleHintReturnMask()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleHintReturnMask, sizeof(QStyleHintReturnMask), typeid(QStyleHintReturnMask), false, &deleter_QStyleHintReturnMask, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStyleHintReturnMask(QStyleHintReturnMask)
void __qt_construct_QStyleHintReturnMask_cref_QStyleHintReturnMask(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturnMask(QStyleHintReturnMask)")
    jobject other0 = __java_arguments[0].l;
    const QStyleHintReturnMask& __qt_other0 = qtjambi_cast<const QStyleHintReturnMask& >(__jni_env, other0);
    QStyleHintReturnMask *__qt_this = new(__qtjambi_ptr) QStyleHintReturnMask(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStyleHintReturnMask::QStyleHintReturnMask(QStyleHintReturnMask)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnMask_initialize_1native__Lio_qt_widgets_QStyleHintReturnMask_2Lio_qt_widgets_QStyleHintReturnMask_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleHintReturnMask::QStyleHintReturnMask(QStyleHintReturnMask)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleHintReturnMask_cref_QStyleHintReturnMask, sizeof(QStyleHintReturnMask), typeid(QStyleHintReturnMask), false, &deleter_QStyleHintReturnMask, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleHintReturnMask
void __qt_destruct_QStyleHintReturnMask(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleHintReturnMask")
    reinterpret_cast<QStyleHintReturnMask*>(ptr)->~QStyleHintReturnMask();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnMask_setRegion_1native_1cref_1QRegion__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID region0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturnMask *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturnMask>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QRegion& __qt_region0 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(region0);
        __qt_this->region = __qt_region0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnMask_region_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturnMask *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturnMask>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QRegion&  __qt_value = __qt_this->region;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnMask_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleHintReturnMask *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturnMask>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleHintReturnMask(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleHintReturnMask>("QStyleHintReturnMask", "io/qt/widgets/QStyleHintReturnMask");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleHintReturnMask, {
        ConstructorInfo(&__qt_construct_QStyleHintReturnMask, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleHintReturnMask_cref_QStyleHintReturnMask, "Lio/qt/widgets/QStyleHintReturnMask;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleHintReturnMask);
    registerMetaType<QStyleHintReturnMask>("QStyleHintReturnMask");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
